@@ -7,12 +7,12 @@ licence: https://opensource.org/licenses/MIT
 
 from importlib import import_module
 from pathlib import Path
-from pkg_resources import resource_listdir
+from importlib.resources import files
 
 
 # import all modules in this directory into module namespace
 globals().update({
-    Path(_file).stem: import_module('.' + Path(_file).stem, __package__)
-    for _file in resource_listdir(__name__, '')
-    if not _file.startswith('_')
+    Path(_file).stem: import_module('.' + Path(_file.name).stem, __package__)
+    for _file in files(__name__).iterdir()
+    if not _file.name.startswith('_')
 })
