@@ -13,7 +13,7 @@ from ..properties import Props
 from ..storage import loaders, savers
 from ..font import Font
 from ..glyph import Glyph
-from ..streams import FileFormatError
+from ..magic import FileFormatError
 from ..binary import ceildiv
 
 from .raw import load_bitmap
@@ -22,8 +22,12 @@ from .raw import load_bitmap
 _FONTX_MAGIC = b'FONTX2'
 
 
-@loaders.register(name='fontx', magic=(_FONTX_MAGIC,))
-def load_fontx(instream, where=None):
+@loaders.register(
+    name='fontx',
+    magic=(_FONTX_MAGIC,),
+    patterns=('*.fnt',),
+)
+def load_fontx(instream):
     """Load font from fontx file."""
     fontx_props, glyphs = _read_fontx(instream)
     logging.info('fontx properties:')
@@ -34,7 +38,7 @@ def load_fontx(instream, where=None):
 
 
 @savers.register(linked=load_fontx)
-def save_fontx(fonts, outstream, where=None, endianness:str='little'):
+def save_fontx(fonts, outstream, endianness:str='little'):
     """Save font to fontx file."""
     if len(fonts) > 1:
         raise FileFormatError('Can only save one font to fontx file.')
