@@ -12,18 +12,18 @@ this implementation leans heavily on Alexander Taylor's os2font
 import logging
 
 from ...storage import loaders, savers
-from ...streams import FileFormatError
+from ...magic import FileFormatError, Magic
 from ...font import Font
 
-from .gpifont import convert_os2_font_resource, GPI_MAGIC
+from .gpifont import convert_os2_font_resource, GPI_MAGIC, OS2FNT_SIGNATURE
 
 
 @loaders.register(
-    #'fnt',
     name='gpi',
-    magic=(GPI_MAGIC,)
+    magic=(GPI_MAGIC + Magic.offset(4) + OS2FNT_SIGNATURE.encode('ascii'),),
+    patterns=('*.fnt',),
 )
-def load_os2(instream, where=None,):
+def load_os2(instream):
     """Load a bare OS/2 GPI font resource."""
     resource = instream.read()
     return convert_os2_font_resource(resource)
