@@ -71,7 +71,7 @@ class YaffParams:
     empty = '-'
 
     # string to be quoted if one of these chars at start and/or end
-    quotable = ('"', "'", ':', ' ')
+    quotable = (':', ' ')
     glyphchars = (ink, paper, empty)
 
 ##############################################################################
@@ -406,6 +406,7 @@ def _quote_if_needed(value):
             not value
             or value[0] in YaffParams.quotable
             or value[-1] in YaffParams.quotable
+            or value[0] == value[-1] == '"'
             or all(_c in YaffParams.glyphchars for _c in value)
         ):
         return f'"{value}"'
